<h1 align="center"><a href="https://freesemt.github.io/molass-legacy"><img src="docs/_static/molass-legacy.png" width="400"></a></h1>

> [!WARNING]
> This package is scheduled to be available in August, 2025.

This repository includes legacy codes of [MOLASS](https://www.jstage.jst.go.jp/article/biophysico/20/1/20_e200001/_article).

To install this package, use pip as follows.

```
pip install -U molass_legacy
pip install -U molass
```

> [!NOTE]
> The molass_legacy package currently depends mutually on molass, which is the package name of
`Molass Library` referenced below. This mutual dependence is planned to be changed to one-way dependence from molass_legacy to molass.<br>The meaning of the planned change is as follows.<br>The molass package is a rewrite of molass_legacy and they have quite a lot in commmon, which will be rearranged and unified into the molass side.

For details, see also:

- **Legacy Reference:** https://freesemt.github.io/molass-legacy for legacy function reference

See also:

- **Molass Library Repository:** https://github.com/nshimizu0721/molass-library

<br>